% 3D
% Plots the tilt against z and time at x=y=0
% Outputs: tilt,z,time
fname='result%3.3d.dat';

% open the mesh file
fid=fopen('mesh.txt');
fscanf(fid,'%s',8);

% find nodes at x=y=0, store node number and z coordinate
out = fscanf(fid,'%f',[4,inf])';
ind = find(out(:,2) == min(out(:,2)) & out(:,3) == min(out(:,3)));
nodes = [floor(out(ind,1)),out(ind,4)];
% Sort with respect to z coordinate
nodes = sortrows(nodes,2); %{node number,z}

% Determine the number of files in the folder
str=sprintf(fname,1);	

nFiles = 1;
while exist(str)~=0
	nFiles = nFiles + 1;
	str=sprintf(fname,nFiles);
end;
nFiles = nFiles - 1;
nNodes = length(nodes);

% Allocate Arrays
tilt=zeros(nFiles,nNodes);
twist=zeros(nFiles,nNodes);
volts=zeros(nFiles,nNodes);
out=[1:1:6];
time=[1:1:nFiles];

% Start Reading the data
for file=1:nFiles
	str=sprintf(fname,file);

	% Get the result time
	fid = fopen(str);
	fscanf(fid,'%s',4);
	time(file) = fscanf(fid,'%f',1);
	% get the z compression ratio
	sScale=fscanf(fid,'%s',5);
	zScale = fscanf(fid,'%f',1);
	
	fclose(fid);

	if sScale(1)=='*'
		res=dlmread(str,'',3,0);
	else
		res=dlmread(str,'',2,0);
	end

	for i=1:nNodes
		out(1:5)=res(nodes(i,1),1:5);
		tilt(file,i)=180*atan2(out(4),sqrt(out(3)^2+out(2)^2))/pi;
		twist(file,i)=180*atan2(out(3),out(2))/pi;
		volts(file,i)=out(5);
	end
end
if sScale(1)~='*' zScale=1;end;

% Produce a plot
midnode=find(nodes(:,2)==nodes(nNodes,2)/2);

z = nodes(:,2)*zScale;
subplot(1,3,1), surf(z,time*1000,tilt);
xlabel('z [\mum]');
ylabel('Time [ms]');
zlabel('Tilt [degrees]');
grid on

% TWIST
subplot(1,3,2), surf(z,time*1000,twist);
xlabel('z [\mum]');
ylabel('Time [ms]');
zlabel('Twist [degrees]');
grid on

% VOLTAGE
subplot(1,3,3), surf(z,time*1000,volts);
xlabel('z [\mum]');
ylabel('Time [ms]');
zlabel('Voltage [V]');
grid on
